@@ -23,13 +23,16 @@ from giza.config.runtime import RuntimeStateConfig
 
 import giza.operations.generate
 import giza.operations.includes
+import giza.operations.packaging
+import giza.operations.git
+import giza.operations.tx
+
 from giza.operations.configuration import render_config
 from giza.operations.clean import clean
-from giza.operations.git import apply_patch, pull_rebase, cherry_pick
 from giza.operations.sphinx import sphinx
 from giza.operations.deploy import deploy, push
 
-def main():
+def get_base_parser():
     parser = argh.ArghParser()
     parser.add_argument('--level', '-l',
                         choices=['debug', 'warning', 'info', 'critical', 'error'],
@@ -37,15 +40,25 @@ def main():
     parser.add_argument('--serial', '-s', default=None, dest='runner', const='serial', action='store_const')
     parser.add_argument('--force', '-f', default=False, action='store_true')
 
+    return parser
+
+def main():
+    parser = get_base_parser()
+
     commands = [
         render_config,
         clean,
         sphinx,
         deploy, push
     ]
-
     argh.add_commands(parser, commands)
-    argh.add_commands(parser, [apply_patch, pull_rebase, cherry_pick], namespace='git')
+
+    git_commands = [
+        giza.operations.git.apply_patch,
+        giza.operations.git.pull_rebase,
+        giza.operations.git.cherry_pick,
+    ]
+    argh.add_commands(parser, git_commands, namespace='git')
 
     generate_commands = [
         giza.operations.generate.api,
@@ -58,7 +71,6 @@ def main():
         giza.operations.generate.tables,
         giza.operations.generate.toc,
     ]
-
     argh.add_commands(parser, generate_commands, namespace='generate')
 
     include_commands = [
@@ -70,9 +82,24 @@ def main():
         giza.operations.includes.graph,
         giza.operations.includes.clean,
     ]
-
     argh.add_commands(parser, include_commands, namespace='includes')
 
+    packaging_commands = [
+        giza.operations.packaging.fetch,
+        giza.operations.packaging.unwind,
+        giza.operations.packaging.create,
+        giza.operations.packaging.deploy,
+    ]
+    argh.add_commands(parser, packaging_commands, namespace='package')
+
+    translation_commands = [
+        giza.operations.tx.check_orphaned,
+        giza.operations.tx.update_translations,
+        giza.operations.tx.pull_translations,
+        giza.operations.tx.push_translations,
+    ]
+    argh.add_commands(parser, translation_commands, namespace='tx')
+
     args = RuntimeStateConfig()
     argh.dispatch(parser, namespace=args)
 
