@@ -34,6 +34,7 @@ class ConfigurationBase(object):
         elif not isinstance(input_obj, ConfigurationBase) and os.path.exists(input_obj):
             input_obj = ingest_yaml_doc(input_obj)
         else:
+            print(input_obj)
             msg = 'cannot ingest Configuration obj from object with type {0}'.format(type(input_obj))
             logger.critical(msg)
             raise TypeError(msg)
@@ -85,13 +86,15 @@ class ConfigurationBase(object):
             return False
 
     def __repr__(self):
-        return str(self.state)
+        return str(self.dict())
 
     def dict(self):
         d = {}
         for k,v in self.state.items():
             if k.startswith('_'):
                 continue
+            elif k in ('pass', 'password', 'token'):
+                d[k] = 'redacted'
             elif isinstance(v, ConfigurationBase):
                 d[k] = v.dict()
             elif isinstance(v, list) and len(v) > 0 and isinstance(v[0], ConfigurationBase):
